@@ -113,6 +113,11 @@ class Experimento:
             self.objeto_relevante_3 = puntos_importantes[2]
             self.objeto_relevante_4 = puntos_importantes[3]
 
+        self.lista_objetos_relevantes = [self.objeto_relevante_1,
+                                         self.objeto_relevante_2,
+                                         self.objeto_relevante_3,
+                                         self.objeto_relevante_4]
+
         self.regiones_preferidas = arreglo_regiones_preferidas
         total_regiones = list(range(0, cantidad_columnas*cantidad_filas))
         self.regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
@@ -1185,7 +1190,7 @@ class Experimento:
 
             cilindros.calcula_alturas_volumenes_circulares_objetos_relevantes(posiciones_x=self.posiciones_x,
                                                                               posiciones_y=self.posiciones_y,
-                                                                              lista_objetos_relevantes=objetos_seleccionados,
+                                                                              lista_objetos_relevantes=self.lista_objetos_relevantes,
                                                                               tamanio=tamanio_volumenes,
                                                                               divisiones=div_volumenes,
                                                                               tipo=tipo_grafica_volumen)
