@@ -4,10 +4,10 @@ class ConfigGrafica:
         self.limite_eje_x_max = None
         self.limite_eje_y_min = None
         self.limite_eje_y_max = None
-        self.objeto_1 = True
-        self.objeto_2 = True
-        self.objeto_3 = True
-        self.objeto_4 = True
+        self.tomar_objeto_1 = True
+        self.tomar_objeto_2 = True
+        self.tomar_objeto_3 = True
+        self.tomar_objeto_4 = True
         self.angulo = 220
         self.dist_max_figuras = 24
         self.total_figuras = 2
@@ -27,10 +27,10 @@ class ConfigGrafica:
         return limites_eje_x, limites_eje_y
 
     def regresa_config_grafica_distancias(self):
-        objetos_a_utilizar = [self.objeto_1,
-                              self.objeto_2,
-                              self.objeto_3,
-                              self.objeto_4]
+        objetos_a_utilizar = [self.tomar_objeto_1,
+                              self.tomar_objeto_2,
+                              self.tomar_objeto_3,
+                              self.tomar_objeto_4]
         return objetos_a_utilizar
 
     def regresa_config_grafica_figuras(self):
